@@ -1,10 +1,10 @@
 /*******************************************************************************
- * SAT4J: a SATisfiability library for Java Copyright (C) 2004-2008 Daniel Le Berre
+ * SAT4J: a SATisfiability library for Java Copyright (C) 2004, 2012 Artois University and CNRS
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ *  http://www.eclipse.org/legal/epl-v10.html
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU Lesser General Public License Version 2.1 or later (the
@@ -15,15 +15,17 @@
  * the provisions above and replace them with the notice and other provisions
  * required by the LGPL. If you do not delete the provisions above, a recipient
  * may use your version of this file under the terms of the EPL or the LGPL.
- * 
+ *
  * Based on the original MiniSat specification from:
- * 
+ *
  * An extensible SAT solver. Niklas Een and Niklas Sorensson. Proceedings of the
  * Sixth International Conference on Theory and Applications of Satisfiability
  * Testing, LNCS 2919, pp 502-518, 2003.
  *
  * See www.minisat.se for the original solver in C++.
- * 
+ *
+ * Contributors:
+ *   CRIL - initial API and implementation
  *******************************************************************************/
 package org.sat4j.minisat.constraints;
 
@@ -48,56 +50,57 @@ import org.sat4j.specs.IVecInt;
  */
 public class MixedDataStructureDanielHT extends AbstractDataStructureFactory {
 
-	private static final long serialVersionUID = 1L;
+    private static final long serialVersionUID = 1L;
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see
-	 * org.sat4j.minisat.DataStructureFactory#createCardinalityConstraint(org
-	 * .sat4j.datatype.VecInt, int)
-	 */
-	@Override
-	public Constr createCardinalityConstraint(IVecInt literals, int degree)
-			throws ContradictionException {
-		return AtLeast.atLeastNew(solver, getVocabulary(), literals, degree);
-	}
+    /*
+     * (non-Javadoc)
+     * 
+     * @see
+     * org.sat4j.minisat.DataStructureFactory#createCardinalityConstraint(org
+     * .sat4j.datatype.VecInt, int)
+     */
+    @Override
+    public Constr createCardinalityConstraint(IVecInt literals, int degree)
+            throws ContradictionException {
+        return AtLeast.atLeastNew(this.solver, getVocabulary(), literals,
+                degree);
+    }
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see
-	 * org.sat4j.minisat.DataStructureFactory#createClause(org.sat4j.datatype
-	 * .VecInt)
-	 */
-	public Constr createClause(IVecInt literals) throws ContradictionException {
-		IVecInt v = Clauses.sanityCheck(literals, getVocabulary(), solver);
-		if (v == null) {
-			// tautological clause
-			return null;
-		}
-		if (v.size() == 1) {
-			return new UnitClause(v.last());
-		}
-		if (v.size() == 2) {
-			return OriginalBinaryClause.brandNewClause(solver, getVocabulary(),
-					v);
-		}
-		return OriginalHTClause.brandNewClause(solver, getVocabulary(), v);
-	}
+    /*
+     * (non-Javadoc)
+     * 
+     * @see
+     * org.sat4j.minisat.DataStructureFactory#createClause(org.sat4j.datatype
+     * .VecInt)
+     */
+    public Constr createClause(IVecInt literals) throws ContradictionException {
+        IVecInt v = Clauses.sanityCheck(literals, getVocabulary(), this.solver);
+        if (v == null) {
+            // tautological clause
+            return null;
+        }
+        if (v.size() == 1) {
+            return new UnitClause(v.last());
+        }
+        if (v.size() == 2) {
+            return OriginalBinaryClause.brandNewClause(this.solver,
+                    getVocabulary(), v);
+        }
+        return OriginalHTClause.brandNewClause(this.solver, getVocabulary(), v);
+    }
 
-	public Constr createUnregisteredClause(IVecInt literals) {
-		if (literals.size() == 1) {
-			return new UnitClause(literals.last());
-		}
-		if (literals.size() == 2) {
-			return new LearntBinaryClause(literals, getVocabulary());
-		}
-		return new LearntHTClause(literals, getVocabulary());
-	}
+    public Constr createUnregisteredClause(IVecInt literals) {
+        if (literals.size() == 1) {
+            return new UnitClause(literals.last());
+        }
+        if (literals.size() == 2) {
+            return new LearntBinaryClause(literals, getVocabulary());
+        }
+        return new LearntHTClause(literals, getVocabulary());
+    }
 
-	@Override
-	protected ILits createLits() {
-		return new Lits();
-	}
+    @Override
+    protected ILits createLits() {
+        return new Lits();
+    }
 }
