@@ -1,10 +1,10 @@
 /*******************************************************************************
- * SAT4J: a SATisfiability library for Java Copyright (C) 2004-2008 Daniel Le Berre
+ * SAT4J: a SATisfiability library for Java Copyright (C) 2004, 2012 Artois University and CNRS
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ *  http://www.eclipse.org/legal/epl-v10.html
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU Lesser General Public License Version 2.1 or later (the
@@ -15,18 +15,21 @@
  * the provisions above and replace them with the notice and other provisions
  * required by the LGPL. If you do not delete the provisions above, a recipient
  * may use your version of this file under the terms of the EPL or the LGPL.
- * 
+ *
  * Based on the original MiniSat specification from:
- * 
+ *
  * An extensible SAT solver. Niklas Een and Niklas Sorensson. Proceedings of the
  * Sixth International Conference on Theory and Applications of Satisfiability
  * Testing, LNCS 2919, pp 502-518, 2003.
  *
  * See www.minisat.se for the original solver in C++.
- * 
+ *
+ * Contributors:
+ *   CRIL - initial API and implementation
  *******************************************************************************/
 package org.sat4j.minisat.restarts;
 
+import org.sat4j.minisat.core.Constr;
 import org.sat4j.minisat.core.RestartStrategy;
 import org.sat4j.minisat.core.SearchParams;
 
@@ -38,30 +41,55 @@ import org.sat4j.minisat.core.SearchParams;
  */
 public final class MiniSATRestarts implements RestartStrategy {
 
-	/**
+    /**
      * 
      */
-	private static final long serialVersionUID = 1L;
+    private static final long serialVersionUID = 1L;
 
-	private double nofConflicts;
+    private double nofConflicts;
 
-	private SearchParams params;
+    private SearchParams params;
 
-	public void init(SearchParams theParams) {
-		this.params = theParams;
-		nofConflicts = theParams.getInitConflictBound();
-	}
+    private int conflictcount;
 
-	public long nextRestartNumberOfConflict() {
-		return Math.round(nofConflicts);
-	}
+    public void init(SearchParams theParams) {
+        this.params = theParams;
+        this.nofConflicts = theParams.getInitConflictBound();
+    }
 
-	public void onRestart() {
-		nofConflicts *= params.getConflictBoundIncFactor();
-	}
+    public long nextRestartNumberOfConflict() {
+        return Math.round(this.nofConflicts);
+    }
 
-	@Override
-	public String toString() {
-		return "MiniSAT restarts strategy";
-	}
+    public void onRestart() {
+        this.nofConflicts *= this.params.getConflictBoundIncFactor();
+    }
+
+    @Override
+    public String toString() {
+        return "MiniSAT restarts strategy";
+    }
+
+    public boolean shouldRestart() {
+        return this.conflictcount >= this.nofConflicts;
+    }
+
+    public void onBackjumpToRootLevel() {
+        this.conflictcount = 0;
+    }
+
+    public void reset() {
+        this.conflictcount = 0;
+    }
+
+    public void newConflict() {
+        this.conflictcount++;
+    }
+
+    public SearchParams getSearchParams() {
+        return this.params;
+    }
+
+    public void newLearnedClause(Constr learned, int trailLevel) {
+    }
 }
